@@ -1,8 +1,9 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # Sometimes this might fail due to upstream changes.
 # In that case, you probably just need to override the failing step in our
 # DownloadOnlyRustBuild class below.
 
+import shutil
 import sys
 
 import bootstrap
@@ -25,7 +26,13 @@ def main(argv):
     triple = argv.pop(1)
     DownloadOnlyRustBuild.triple = triple
     bootstrap.RustBuild = DownloadOnlyRustBuild
-    bootstrap.bootstrap(False)
+    args = bootstrap.parse_args(argv)
+    # bootstrap.py likes to delete our .cargo directory out from under us
+    shutil.move(".cargo", ".cargo-bak")
+    try:
+        bootstrap.bootstrap(args)
+    finally:
+        shutil.move(".cargo-bak", ".cargo")
 
 if __name__ == '__main__':
     main(sys.argv)
